@@ -9,6 +9,7 @@ class NGramSpellChecker(SimpleSpellChecker):
 
     __nGram: NGram
     __rootNgram: bool
+    __threshold: float
 
     def __init__(self, fsm: FsmMorphologicalAnalyzer, nGram: NGram, rootNGram: bool):
         """
@@ -26,6 +27,7 @@ class NGramSpellChecker(SimpleSpellChecker):
         super().__init__(fsm)
         self.__nGram = nGram
         self.__rootNgram = rootNGram
+        self.__threshold = 0.0
 
     def checkAnalysisAndSetRoot(self, sentence: Sentence, index: int) -> Word:
         """
@@ -44,6 +46,9 @@ class NGramSpellChecker(SimpleSpellChecker):
                     return sentence.getWord(index)
         return None
 
+    def setThreshold(self, threshold: float):
+        self.__threshold = threshold
+
     def spellCheck(self, sentence: Sentence) -> Sentence:
         """
         The spellCheck method takes a Sentence as an input and loops i times where i ranges from 0 to size of words in
@@ -80,7 +85,7 @@ class NGramSpellChecker(SimpleSpellChecker):
                 candidates = self.candidateList(word)
                 bestCandidate = word.getName()
                 bestRoot = word
-                bestProbability = 0.0
+                bestProbability = self.__threshold
                 for candidate in candidates:
                     fsmParses = self.fsm.morphologicalAnalysis(candidate)
                     if self.__rootNgram:
